@@ -223,7 +223,7 @@ rclc_executor_add_subscription(
   }
 
   // assign data fields
-  executor->handles[executor->index].type = SUBSCRIPTION;
+  executor->handles[executor->index].type = RCLC_SUBSCRIPTION;
   executor->handles[executor->index].subscription = subscription;
   executor->handles[executor->index].data = msg;
   executor->handles[executor->index].subscription_callback = callback;
@@ -273,7 +273,7 @@ rclc_executor_add_subscription_with_context(
   }
 
   // assign data fields
-  executor->handles[executor->index].type = SUBSCRIPTION_WITH_CONTEXT;
+  executor->handles[executor->index].type = RCLC_SUBSCRIPTION_WITH_CONTEXT;
   executor->handles[executor->index].subscription = subscription;
   executor->handles[executor->index].data = msg;
   executor->handles[executor->index].subscription_callback_with_context = callback;
@@ -318,7 +318,7 @@ rclc_executor_add_timer(
   }
 
   // assign data fields
-  executor->handles[executor->index].type = TIMER;
+  executor->handles[executor->index].type = RCLC_TIMER;
   executor->handles[executor->index].timer = timer;
   executor->handles[executor->index].invocation = ON_NEW_DATA;  // i.e. when timer elapsed
   executor->handles[executor->index].initialized = true;
@@ -362,7 +362,7 @@ rclc_executor_add_client(
   }
 
   // assign data fields
-  executor->handles[executor->index].type = CLIENT;
+  executor->handles[executor->index].type = RCLC_CLIENT;
   executor->handles[executor->index].client = client;
   executor->handles[executor->index].data = response_msg;
   executor->handles[executor->index].client_callback = callback;
@@ -408,7 +408,7 @@ rclc_executor_add_client_with_request_id(
   }
 
   // assign data fields
-  executor->handles[executor->index].type = CLIENT_WITH_REQUEST_ID;
+  executor->handles[executor->index].type = RCLC_CLIENT_WITH_REQUEST_ID;
   executor->handles[executor->index].client = client;
   executor->handles[executor->index].data = response_msg;
   executor->handles[executor->index].client_callback_with_reqid = callback;
@@ -456,7 +456,7 @@ rclc_executor_add_service(
   }
 
   // assign data fields
-  executor->handles[executor->index].type = SERVICE;
+  executor->handles[executor->index].type = RCLC_SERVICE;
   executor->handles[executor->index].service = service;
   executor->handles[executor->index].data = request_msg;
   // TODO(jst3si) new type with req and resp message in data field.
@@ -507,7 +507,7 @@ rclc_executor_add_service_with_context(
   }
 
   // assign data fields
-  executor->handles[executor->index].type = SERVICE_WITH_CONTEXT;
+  executor->handles[executor->index].type = RCLC_SERVICE_WITH_CONTEXT;
   executor->handles[executor->index].service = service;
   executor->handles[executor->index].data = request_msg;
   // TODO(jst3si) new type with req and resp message in data field.
@@ -557,7 +557,7 @@ rclc_executor_add_service_with_request_id(
   }
 
   // assign data fields
-  executor->handles[executor->index].type = SERVICE_WITH_REQUEST_ID;
+  executor->handles[executor->index].type = RCLC_SERVICE_WITH_REQUEST_ID;
   executor->handles[executor->index].service = service;
   executor->handles[executor->index].data = request_msg;
   // TODO(jst3si) new type with req and resp message in data field.
@@ -603,7 +603,7 @@ rclc_executor_add_guard_condition(
   }
 
   // assign data fields
-  executor->handles[executor->index].type = GUARD_CONDITION;
+  executor->handles[executor->index].type = RCLC_GUARD_CONDITION;
   executor->handles[executor->index].gc = gc;
   executor->handles[executor->index].gc_callback = callback;
   executor->handles[executor->index].invocation = ON_NEW_DATA;  // invoce when request came in
@@ -857,7 +857,7 @@ rclc_executor_add_action_client(
   }
 
   // assign data fields
-  executor->handles[executor->index].type = ACTION_CLIENT;
+  executor->handles[executor->index].type = RCLC_ACTION_CLIENT;
   executor->handles[executor->index].action_client = action_client;
   executor->handles[executor->index].action_client->goal_callback = goal_callback;
   executor->handles[executor->index].action_client->feedback_callback = feedback_callback;
@@ -963,7 +963,7 @@ rclc_executor_add_action_server(
   }
 
   // assign data fields
-  executor->handles[executor->index].type = ACTION_SERVER;
+  executor->handles[executor->index].type = RCLC_ACTION_SERVER;
   executor->handles[executor->index].action_server = action_server;
   executor->handles[executor->index].action_server->goal_callback = goal_callback;
   executor->handles[executor->index].action_server->cancel_callback = cancel_callback;
@@ -1029,34 +1029,34 @@ _rclc_check_for_new_data(rclc_executor_handle_t * handle, rcl_wait_set_t * wait_
   rcl_ret_t rc = RCL_RET_OK;
 
   switch (handle->type) {
-    case SUBSCRIPTION:
-    case SUBSCRIPTION_WITH_CONTEXT:
+    case RCLC_SUBSCRIPTION:
+    case RCLC_SUBSCRIPTION_WITH_CONTEXT:
       handle->data_available = (NULL != wait_set->subscriptions[handle->index]);
       break;
 
-    case TIMER:
-      // case TIMER_WITH_CONTEXT:
+    case RCLC_TIMER:
+      // case RCLC_TIMER_WITH_CONTEXT:
       handle->data_available = (NULL != wait_set->timers[handle->index]);
       break;
 
-    case SERVICE:
-    case SERVICE_WITH_REQUEST_ID:
-    case SERVICE_WITH_CONTEXT:
+    case RCLC_SERVICE:
+    case RCLC_SERVICE_WITH_REQUEST_ID:
+    case RCLC_SERVICE_WITH_CONTEXT:
       handle->data_available = (NULL != wait_set->services[handle->index]);
       break;
 
-    case CLIENT:
-    case CLIENT_WITH_REQUEST_ID:
-      // case CLIENT_WITH_CONTEXT:
+    case RCLC_CLIENT:
+    case RCLC_CLIENT_WITH_REQUEST_ID:
+      // case RCLC_CLIENT_WITH_CONTEXT:
       handle->data_available = (NULL != wait_set->clients[handle->index]);
       break;
 
-    case GUARD_CONDITION:
-      // case GUARD_CONDITION_WITH_CONTEXT:
+    case RCLC_GUARD_CONDITION:
+      // case RCLC_GUARD_CONDITION_WITH_CONTEXT:
       handle->data_available = (NULL != wait_set->guard_conditions[handle->index]);
       break;
 
-    case ACTION_CLIENT:
+    case RCLC_ACTION_CLIENT:
       rc = rcl_action_client_wait_set_get_entities_ready(
         wait_set,
         &handle->action_client->rcl_handle,
@@ -1068,7 +1068,7 @@ _rclc_check_for_new_data(rclc_executor_handle_t * handle, rcl_wait_set_t * wait_
       );
       break;
 
-    case ACTION_SERVER:
+    case RCLC_ACTION_SERVER:
       rc = rcl_action_server_wait_set_get_entities_ready(
         wait_set,
         &handle->action_server->rcl_handle,
@@ -1100,8 +1100,8 @@ _rclc_take_new_data(rclc_executor_handle_t * handle, rcl_wait_set_t * wait_set)
   rcl_ret_t rc = RCL_RET_OK;
 
   switch (handle->type) {
-    case SUBSCRIPTION:
-    case SUBSCRIPTION_WITH_CONTEXT:
+    case RCLC_SUBSCRIPTION:
+    case RCLC_SUBSCRIPTION_WITH_CONTEXT:
       if (wait_set->subscriptions[handle->index]) {
         rmw_message_info_t messageInfo;
         rc = rcl_take(
@@ -1122,13 +1122,13 @@ _rclc_take_new_data(rclc_executor_handle_t * handle, rcl_wait_set_t * wait_set)
       }
       break;
 
-    case TIMER:
-      // case TIMER_WITH_CONTEXT:
+    case RCLC_TIMER:
+      // case RCLC_TIMER_WITH_CONTEXT:
       // nothing to do
       // notification, that timer is ready already done in _rclc_evaluate_data_availability()
       break;
 
-    case ACTION_CLIENT:
+    case RCLC_ACTION_CLIENT:
       if (handle->action_client->goal_response_available) {
         Generic_SendGoal_Response aux_goal_response;
         rmw_request_id_t aux_goal_response_header;
@@ -1218,7 +1218,7 @@ _rclc_take_new_data(rclc_executor_handle_t * handle, rcl_wait_set_t * wait_set)
       }
       break;
 
-    case ACTION_SERVER:
+    case RCLC_ACTION_SERVER:
       if (handle->action_server->goal_request_available) {
         rclc_action_goal_handle_t * goal_handle =
           rclc_action_take_goal_handle(handle->action_server);
@@ -1292,9 +1292,9 @@ _rclc_take_new_data(rclc_executor_handle_t * handle, rcl_wait_set_t * wait_set)
       }
       break;
 
-    case SERVICE:
-    case SERVICE_WITH_REQUEST_ID:
-    case SERVICE_WITH_CONTEXT:
+    case RCLC_SERVICE:
+    case RCLC_SERVICE_WITH_REQUEST_ID:
+    case RCLC_SERVICE_WITH_CONTEXT:
       if (wait_set->services[handle->index]) {
         rc = rcl_take_request(
           handle->service, &handle->req_id, handle->data);
@@ -1313,9 +1313,9 @@ _rclc_take_new_data(rclc_executor_handle_t * handle, rcl_wait_set_t * wait_set)
       }
       break;
 
-    case CLIENT:
-    case CLIENT_WITH_REQUEST_ID:
-      // case CLIENT_WITH_CONTEXT:
+    case RCLC_CLIENT:
+    case RCLC_CLIENT_WITH_REQUEST_ID:
+      // case RCLC_CLIENT_WITH_CONTEXT:
       if (wait_set->clients[handle->index]) {
         rc = rcl_take_response(
           handle->client, &handle->req_id, handle->data);
@@ -1330,8 +1330,8 @@ _rclc_take_new_data(rclc_executor_handle_t * handle, rcl_wait_set_t * wait_set)
       }
       break;
 
-    case GUARD_CONDITION:
-      // case GUARD_CONDITION_WITH_CONTEXT:
+    case RCLC_GUARD_CONDITION:
+      // case RCLC_GUARD_CONDITION_WITH_CONTEXT:
       // nothing to do
       break;
 
@@ -1349,7 +1349,7 @@ bool _rclc_check_handle_data_available(rclc_executor_handle_t * handle)
   RCL_CHECK_ARGUMENT_FOR_NULL(handle, false);
 
   switch (handle->type) {
-    case ACTION_CLIENT:
+    case RCLC_ACTION_CLIENT:
       if (handle->action_client->feedback_available ||
         handle->action_client->status_available ||
         handle->action_client->goal_response_available ||
@@ -1360,7 +1360,7 @@ bool _rclc_check_handle_data_available(rclc_executor_handle_t * handle)
       }
       break;
 
-    case ACTION_SERVER:
+    case RCLC_ACTION_SERVER:
       if (handle->action_server->goal_request_available ||
         handle->action_server->cancel_request_available ||
         handle->action_server->goal_expired_available ||
@@ -1410,7 +1410,7 @@ _rclc_execute(rclc_executor_handle_t * handle)
   // execute callback
   if (invoke_callback) {
     switch (handle->type) {
-      case SUBSCRIPTION:
+      case RCLC_SUBSCRIPTION:
         if (handle->data_available) {
           handle->subscription_callback(handle->data);
         } else {
@@ -1418,7 +1418,7 @@ _rclc_execute(rclc_executor_handle_t * handle)
         }
         break;
 
-      case SUBSCRIPTION_WITH_CONTEXT:
+      case RCLC_SUBSCRIPTION_WITH_CONTEXT:
         if (handle->data_available) {
           handle->subscription_callback_with_context(
             handle->data,
@@ -1430,8 +1430,8 @@ _rclc_execute(rclc_executor_handle_t * handle)
         }
         break;
 
-      case TIMER:
-        // case TIMER_WITH_CONTEXT:
+      case RCLC_TIMER:
+        // case RCLC_TIMER_WITH_CONTEXT:
         rc = rcl_timer_call(handle->timer);
 
         // cancled timer are not handled, return success
@@ -1446,23 +1446,23 @@ _rclc_execute(rclc_executor_handle_t * handle)
         }
         break;
 
-      case SERVICE:
-      case SERVICE_WITH_REQUEST_ID:
-      case SERVICE_WITH_CONTEXT:
+      case RCLC_SERVICE:
+      case RCLC_SERVICE_WITH_REQUEST_ID:
+      case RCLC_SERVICE_WITH_CONTEXT:
         // differentiate user-side service types
         switch (handle->type) {
-          case SERVICE:
+          case RCLC_SERVICE:
             handle->service_callback(
               handle->data,
               handle->data_response_msg);
             break;
-          case SERVICE_WITH_REQUEST_ID:
+          case RCLC_SERVICE_WITH_REQUEST_ID:
             handle->service_callback_with_reqid(
               handle->data,
               &handle->req_id,
               handle->data_response_msg);
             break;
-          case SERVICE_WITH_CONTEXT:
+          case RCLC_SERVICE_WITH_CONTEXT:
             handle->service_callback_with_context(
               handle->data,
               handle->data_response_msg,
@@ -1479,25 +1479,25 @@ _rclc_execute(rclc_executor_handle_t * handle)
         }
         break;
 
-      case CLIENT:
+      case RCLC_CLIENT:
         handle->client_callback(handle->data);
         break;
 
-      case CLIENT_WITH_REQUEST_ID:
+      case RCLC_CLIENT_WITH_REQUEST_ID:
         handle->client_callback_with_reqid(handle->data, &handle->req_id);
         break;
 
-      // case CLIENT_WITH_CONTEXT:   //TODO
+      // case RCLC_CLIENT_WITH_CONTEXT:   //TODO
       //   break;
 
-      case GUARD_CONDITION:
+      case RCLC_GUARD_CONDITION:
         handle->gc_callback();
         break;
 
-      // case GUARD_CONDITION_WITH_CONTEXT:  //TODO
+      // case RCLC_GUARD_CONDITION_WITH_CONTEXT:  //TODO
       //   break;
 
-      case ACTION_CLIENT:
+      case RCLC_ACTION_CLIENT:
         // TODO(pablogs9): Handle action client status
         if (handle->action_client->goal_response_available) {
           // Handle action client goal response messages
@@ -1589,7 +1589,7 @@ _rclc_execute(rclc_executor_handle_t * handle)
         }
         break;
 
-      case ACTION_SERVER:
+      case RCLC_ACTION_SERVER:
         if (handle->action_server->goal_ended) {
           // Handle action server terminated goals (succeeded, canceled or aborted)
           //
@@ -1824,8 +1824,8 @@ rclc_executor_spin_some(rclc_executor_t * executor, const uint64_t timeout_ns)
   for (size_t i = 0; (i < executor->max_handles && executor->handles[i].initialized); i++) {
     RCUTILS_LOG_DEBUG_NAMED(ROS_PACKAGE_NAME, "wait_set_add_* %d", executor->handles[i].type);
     switch (executor->handles[i].type) {
-      case SUBSCRIPTION:
-      case SUBSCRIPTION_WITH_CONTEXT:
+      case RCLC_SUBSCRIPTION:
+      case RCLC_SUBSCRIPTION_WITH_CONTEXT:
         // add subscription to wait_set and save index
         rc = rcl_wait_set_add_subscription(
           &executor->wait_set, executor->handles[i].subscription,
@@ -1841,8 +1841,8 @@ rclc_executor_spin_some(rclc_executor_t * executor, const uint64_t timeout_ns)
         }
         break;
 
-      case TIMER:
-        // case TIMER_WITH_CONTEXT:
+      case RCLC_TIMER:
+        // case RCLC_TIMER_WITH_CONTEXT:
         // add timer to wait_set and save index
         rc = rcl_wait_set_add_timer(
           &executor->wait_set, executor->handles[i].timer,
@@ -1857,9 +1857,9 @@ rclc_executor_spin_some(rclc_executor_t * executor, const uint64_t timeout_ns)
         }
         break;
 
-      case SERVICE:
-      case SERVICE_WITH_REQUEST_ID:
-      case SERVICE_WITH_CONTEXT:
+      case RCLC_SERVICE:
+      case RCLC_SERVICE_WITH_REQUEST_ID:
+      case RCLC_SERVICE_WITH_CONTEXT:
         // add service to wait_set and save index
         rc = rcl_wait_set_add_service(
           &executor->wait_set, executor->handles[i].service,
@@ -1875,9 +1875,9 @@ rclc_executor_spin_some(rclc_executor_t * executor, const uint64_t timeout_ns)
         break;
 
 
-      case CLIENT:
-      case CLIENT_WITH_REQUEST_ID:
-        // case CLIENT_WITH_CONTEXT:
+      case RCLC_CLIENT:
+      case RCLC_CLIENT_WITH_REQUEST_ID:
+        // case RCLC_CLIENT_WITH_CONTEXT:
         // add client to wait_set and save index
         rc = rcl_wait_set_add_client(
           &executor->wait_set, executor->handles[i].client,
@@ -1892,8 +1892,8 @@ rclc_executor_spin_some(rclc_executor_t * executor, const uint64_t timeout_ns)
         }
         break;
 
-      case GUARD_CONDITION:
-        // case GUARD_CONDITION_WITH_CONTEXT:
+      case RCLC_GUARD_CONDITION:
+        // case RCLC_GUARD_CONDITION_WITH_CONTEXT:
         // add guard_condition to wait_set and save index
         rc = rcl_wait_set_add_guard_condition(
           &executor->wait_set, executor->handles[i].gc,
@@ -1908,7 +1908,7 @@ rclc_executor_spin_some(rclc_executor_t * executor, const uint64_t timeout_ns)
         }
         break;
 
-      case ACTION_CLIENT:
+      case RCLC_ACTION_CLIENT:
         // add action client to wait_set and save index
         rc = rcl_action_wait_set_add_action_client(
           &executor->wait_set, &executor->handles[i].action_client->rcl_handle,
@@ -1924,7 +1924,7 @@ rclc_executor_spin_some(rclc_executor_t * executor, const uint64_t timeout_ns)
         }
         break;
 
-      case ACTION_SERVER:
+      case RCLC_ACTION_SERVER:
         // add action server to wait_set and save index
         rc = rcl_action_wait_set_add_action_server(
           &executor->wait_set, &executor->handles[i].action_server->rcl_handle,
